==> zio-aws-amplifybackend_3-5.17.104.12-sources.jar: zio/aws/amplifybackend/model/GetTokenRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetTokenRequest(appId: __string, sessionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.GetTokenRequest = {
    import GetTokenRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.GetTokenRequest
      .builder()
      .appId(__string.unwrap(appId): java.lang.String)
      .sessionId(__string.unwrap(sessionId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.GetTokenRequest.ReadOnly =
    zio.aws.amplifybackend.model.GetTokenRequest.wrap(buildAwsValue())
}
object GetTokenRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.GetTokenRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.GetTokenRequest =
      zio.aws.amplifybackend.model.GetTokenRequest(appId, sessionId)
    def appId: __string
    def sessionId: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getSessionId: ZIO[Any, Nothing, __string] = ZIO.succeed(sessionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetTokenRequest
  ) extends zio.aws.amplifybackend.model.GetTokenRequest.ReadOnly {
    override val appId: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.appId())
    override val sessionId: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.sessionId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetTokenRequest
  ): zio.aws.amplifybackend.model.GetTokenRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-amplifybackend_3-5.17.161.2-sources.jar: zio/aws/amplifybackend/model/GetTokenRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetTokenRequest(appId: __string, sessionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.GetTokenRequest = {
    import GetTokenRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.GetTokenRequest
      .builder()
      .appId(appId: java.lang.String)
      .sessionId(sessionId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.GetTokenRequest.ReadOnly =
    zio.aws.amplifybackend.model.GetTokenRequest.wrap(buildAwsValue())
}
object GetTokenRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.GetTokenRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.GetTokenRequest =
      zio.aws.amplifybackend.model.GetTokenRequest(appId, sessionId)
    def appId: __string
    def sessionId: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getSessionId: ZIO[Any, Nothing, __string] = ZIO.succeed(sessionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetTokenRequest
  ) extends zio.aws.amplifybackend.model.GetTokenRequest.ReadOnly {
    override val appId: __string = impl.appId(): __string
    override val sessionId: __string = impl.sessionId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetTokenRequest
  ): zio.aws.amplifybackend.model.GetTokenRequest.ReadOnly = new Wrapper(impl)
}
